from setuptools import setup

setup(name='asdf_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['asdf_distributions'],
      author= 'Felipe C',
      zip_safe=False)
